Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1446)

Unified Diff: chrome/browser/policy/user_policy_cache.h

Issue 9111022: Removed ConfigurationPolicyType and extended PolicyMap. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/policy/policy_status_info.cc ('k') | chrome/browser/policy/user_policy_cache.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/policy/user_policy_cache.h
diff --git a/chrome/browser/policy/user_policy_cache.h b/chrome/browser/policy/user_policy_cache.h
index 1696430fa763f25fcd994bb5f8ec7074b2de06d5..c98adfefbf0ec4cf33e79dba75932eaf35c06daf 100644
--- a/chrome/browser/policy/user_policy_cache.h
+++ b/chrome/browser/policy/user_policy_cache.h
@@ -60,8 +60,7 @@ class UserPolicyCache : public CloudPolicyCacheBase,
// CloudPolicyCacheBase implementation:
virtual bool DecodePolicyData(
const enterprise_management::PolicyData& policy_data,
- PolicyMap* mandatory,
- PolicyMap* recommended) OVERRIDE;
+ PolicyMap* policies) OVERRIDE;
// Checks if this cache is ready, and invokes SetReady() if so.
void CheckIfReady();
@@ -70,13 +69,12 @@ class UserPolicyCache : public CloudPolicyCacheBase,
// The following member functions are needed to support old-style policy and
// can be removed once all server-side components (CPanel, D3) have been
// migrated to providing the new policy format.
-
- // If |mandatory| and |recommended| are both empty, and |policy_data|
- // contains a field named "repeated GenericNamedValue named_value = 2;",
- // this field is decoded into |mandatory|.
+ //
+ // If |policies| is empty and |policy_data| contains a field named
+ // "repeated GenericNamedValue named_value = 2;", the policies in that field
+ // are added to |policies| as LEVEL_MANDATORY, SCOPE_USER policies.
void MaybeDecodeOldstylePolicy(const std::string& policy_data,
- PolicyMap* mandatory,
- PolicyMap* recommended);
+ PolicyMap* policies);
Value* DecodeIntegerValue(google::protobuf::int64 value) const;
Value* DecodeValue(const enterprise_management::GenericValue& value) const;
« no previous file with comments | « chrome/browser/policy/policy_status_info.cc ('k') | chrome/browser/policy/user_policy_cache.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698